@@ -18,6 +18,9 @@ if (interactive()) {
         )
 
         check_ui_test(result)
+        warning("The sub-menu items that is displayed on a right-click within the canvas do not disappear even after the mouse pointer is moved away. ",
+                "This makes it difficult to select any item. This issue is specifc to R studio and cannot be reproduced on the web")
+
     })
 } else {
     message("Non-interactive data-url tests skipped")
